.. _numcombine:

**************************
numcombine
**************************
This module allows the user to combine a stack of images into a single image using various methods.

.. currentmodule:: stsci.image.numcombine

.. automodule:: stsci.image.numcombine
   :members:
   :undoc-members:

